@@ -6,5 +6,5 @@ test_that("FilterPerformance", {
 
   f$calculate(task)
   expect_filter(f, task = task)
-  expect_true(all(f$scores < 0))
+  expect_true(all(f$scores <= 0))
 })
