@@ -18,7 +18,7 @@ test_that("Filtering an empty Task (#39)", {
 })
 
 test_that("as.data.table conversion works", {
-  task = mlr_tasks$get("pima")
+  task = mlr_tasks$get("sonar")
   filter = mlr_filters$get("auc")
   filter$calculate(task)
 
@@ -32,7 +32,7 @@ test_that("mlr3sugar creation works", {
 test_that("Assertion of task type works", {
   task = mlr_tasks$get("iris")
   f = mlr_filters$get("correlation")
-  expect_error(f$calculate(task), regexp = "must be numeric")
+  expect_error(f$calculate(task), regexp = "type")
 })
 
 
